--[[	Detailed Durability - Ammo Count Module
	by SDPhantom
	https://www.wowinterface.com/forums/member.php?u=34145
	https://www.curseforge.com/members/sdphantomgamer/projects	]]
--------------------------------------------------------------------------

local AddOn=select(2,...);
if AddOn.IsModernClient then return; end--	Modern WoW doesn't use ammo slots anymore

local GetContainerNumFreeSlots=C_Container and C_Container.GetContainerNumFreeSlots or GetContainerNumFreeSlots;
local GetContainerNumSlots=C_Container and C_Container.GetContainerNumSlots or GetContainerNumSlots;

--------------------------
--[[	Text Setup	]]
--------------------------
local AmmoText=DurabilityFrame:CreateFontString(nil,"OVERLAY","NumberFont_GameNormal");
AmmoText:SetPoint("BOTTOMRIGHT",DurabilityRanged,"BOTTOMRIGHT");
AmmoText:SetJustifyH("RIGHT");
AddOn.ModifyFont(AmmoText,nil,nil,"OUTLINE");

--------------------------
--[[	Update Function	]]
--------------------------
local function UpdateAmmoCount()
	local weaponitemid=GetInventoryItemID("player",INVSLOT_RANGED);
	local ammoitemid,ammoslot=AddOn.GetEquippedAmmo();
	if ammoitemid and not AddOn.IsInfiniteAmmo(ammoitemid) and AddOn.RequestItemData(ammoitemid,UpdateAmmoCount) then--	Returns true if cached, false if requested, nil if neither
--		Stack Size & Count
		local count,stack;
		if AddOn.UsesDurabilityForAmmo(weaponitemid) then count,stack=GetInventoryItemDurability(ammoslot);
		else count,stack=GetInventoryItemCount("player",ammoslot),select(8,GetItemInfo(ammoitemid)); end

		if count and stack then--	Sanity check
--			Calculate ammo capacity (for quivers and ammo bags; otherwise calculating percent range for color)
			local ammobagslots=0; if ammoslot==INVSLOT_AMMO then
				local ammobits=GetItemFamily(ammoitemid);
				for i=BACKPACK_CONTAINER,NUM_BAG_SLOTS do
	--				Note: Unrestricted bags return a mask of zero, non-existant bags return a nil mask
					local _,bagbits=GetContainerNumFreeSlots(i);
					if bagbits and bit.band(ammobits,bagbits)>0 then ammobagslots=ammobagslots+GetContainerNumSlots(i); end
				end
			end

--			Ammo Count Formatting (Stacks+Remain or Count where appropriate)
--			if count>stack then AmmoText:SetFormattedText("%d+%d",math.floor(count/stack),count%stack);
			if ammobagslots>0 then AmmoText:SetFormattedText("%d/%d\n+%d",math.floor(count/stack),ammobagslots,count%stack);
			else AmmoText:SetText(count); end

--			Percentage Coloring
			AmmoText:SetTextColor(AddOn.GetPercentColor(count/(math.max(ammobagslots,1)*stack)));
		else AmmoText:SetText(nil); end
	else AmmoText:SetText(nil); end
end

--------------------------
--[[	Event Handler	]]
--------------------------
local EventFrame=CreateFrame("Frame");
EventFrame:RegisterEvent("PLAYER_LOGIN");--	Login/Reload
EventFrame:RegisterEvent("PLAYER_EQUIPMENT_CHANGED");--	Primary Equipped/Unequipped/Swapped items (Ammo slot doesn't fire this in TBC)
EventFrame:RegisterUnitEvent("UNIT_INVENTORY_CHANGED","player");--	Backup Equipped/Unequipped/Swapped items
EventFrame:RegisterEvent("BAG_UPDATE_DELAYED");--	Ammo count
EventFrame:SetScript("OnEvent",UpdateAmmoCount);
